@@ -1,18 +1,20 @@
-# Copyright (c) 2015-2016, 2018 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2015-2016, 2018-2020 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2015-2016 Ceridwen <ceridwenv@gmail.com>
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
 # Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
 # Copyright (c) 2018 Anthony Sottile <asottile@umich.edu>
+# Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/COPYING.LESSER
+# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
 
 
 from astroid import bases
 from astroid import context as contextmod
-from astroid import exceptions
-from astroid import nodes
-from astroid import util
+from astroid import nodes, util
+from astroid.context import CallContext
+from astroid.exceptions import InferenceError, NoDefault
 
 
 class CallSite:
@@ -20,20 +22,29 @@ class CallSite:
 
     It needs a call context, which contains the arguments and the
     keyword arguments that were passed into a given call site.
-    In order to infer what an argument represents, call
-    :meth:`infer_argument` with the corresponding function node
-    and the argument name.
+    In order to infer what an argument represents, call :meth:`infer_argument`
+    with the corresponding function node and the argument name.
+
+    :param callcontext:
+        An instance of :class:`astroid.context.CallContext`, that holds
+        the arguments for the call site.
+    :param argument_context_map:
+        Additional contexts per node, passed in from :attr:`astroid.context.Context.extra_context`
+    :param context:
+        An instance of :class:`astroid.context.Context`.
     """
 
-    def __init__(self, callcontext, argument_context_map=None):
+    def __init__(
+        self, callcontext: CallContext, argument_context_map=None, context=None
+    ):
         if argument_context_map is None:
             argument_context_map = {}
         self.argument_context_map = argument_context_map
         args = callcontext.args
         keywords = callcontext.keywords
         self.duplicated_keywords = set()
-        self._unpacked_args = self._unpack_args(args)
-        self._unpacked_kwargs = self._unpack_keywords(keywords)
+        self._unpacked_args = self._unpack_args(args, context=context)
+        self._unpacked_kwargs = self._unpack_keywords(keywords, context=context)
 
         self.positional_arguments = [
             arg for arg in self._unpacked_args if arg is not util.Uninferable
@@ -45,10 +56,18 @@ class CallSite:
         }
 
     @classmethod
-    def from_call(cls, call_node):
-        """Get a CallSite object from the given Call node."""
+    def from_call(cls, call_node, context=None):
+        """Get a CallSite object from the given Call node.
+
+        :param context:
+            An instance of :class:`astroid.context.Context` that will be used
+            to force a single inference path.
+        """
+
+        # Determine the callcontext from the given `context` object if any.
+        context = context or contextmod.InferenceContext()
         callcontext = contextmod.CallContext(call_node.args, call_node.keywords)
-        return cls(callcontext)
+        return cls(callcontext, context=context)
 
     def has_invalid_arguments(self):
         """Check if in the current CallSite were passed *invalid* arguments
@@ -70,16 +89,16 @@ class CallSite:
         """
         return len(self.keyword_arguments) != len(self._unpacked_kwargs)
 
-    def _unpack_keywords(self, keywords):
+    def _unpack_keywords(self, keywords, context=None):
         values = {}
-        context = contextmod.InferenceContext()
+        context = context or contextmod.InferenceContext()
         context.extra_context = self.argument_context_map
         for name, value in keywords:
             if name is None:
                 # Then it's an unpacking operation (**)
                 try:
                     inferred = next(value.infer(context=context))
-                except exceptions.InferenceError:
+                except InferenceError:
                     values[name] = util.Uninferable
                     continue
 
@@ -91,7 +110,7 @@ class CallSite:
                 for dict_key, dict_value in inferred.items:
                     try:
                         dict_key = next(dict_key.infer(context=context))
-                    except exceptions.InferenceError:
+                    except InferenceError:
                         values[name] = util.Uninferable
                         continue
                     if not isinstance(dict_key, nodes.Const):
@@ -110,15 +129,15 @@ class CallSite:
                 values[name] = value
         return values
 
-    def _unpack_args(self, args):
+    def _unpack_args(self, args, context=None):
         values = []
-        context = contextmod.InferenceContext()
+        context = context or contextmod.InferenceContext()
         context.extra_context = self.argument_context_map
         for arg in args:
             if isinstance(arg, nodes.Starred):
                 try:
                     inferred = next(arg.value.infer(context=context))
-                except exceptions.InferenceError:
+                except InferenceError:
                     values.append(util.Uninferable)
                     continue
 
@@ -142,7 +161,7 @@ class CallSite:
             context: Inference context object
         """
         if name in self.duplicated_keywords:
-            raise exceptions.InferenceError(
+            raise InferenceError(
                 "The arguments passed to {func!r} " " have duplicate keywords.",
                 call_site=self,
                 func=funcnode,
@@ -158,8 +177,8 @@ class CallSite:
 
         # Too many arguments given and no variable arguments.
         if len(self.positional_arguments) > len(funcnode.args.args):
-            if not funcnode.args.vararg:
-                raise exceptions.InferenceError(
+            if not funcnode.args.vararg and not funcnode.args.posonlyargs:
+                raise InferenceError(
                     "Too many positional arguments "
                     "passed to {func!r} that does "
                     "not have *args.",
@@ -209,7 +228,7 @@ class CallSite:
 
                 if funcnode.type == "method":
                     if not isinstance(boundnode, bases.Instance):
-                        boundnode = bases.Instance(boundnode)
+                        boundnode = boundnode.instantiate_class()
                     return iter((boundnode,))
                 if funcnode.type == "classmethod":
                     return iter((boundnode,))
@@ -228,7 +247,7 @@ class CallSite:
             # It wants all the keywords that were passed into
             # the call site.
             if self.has_invalid_keywords():
-                raise exceptions.InferenceError(
+                raise InferenceError(
                     "Inference failed to find values for all keyword arguments "
                     "to {func!r}: {unpacked_kwargs!r} doesn't correspond to "
                     "{keyword_arguments!r}.",
@@ -252,7 +271,7 @@ class CallSite:
             # It wants all the args that were passed into
             # the call site.
             if self.has_invalid_arguments():
-                raise exceptions.InferenceError(
+                raise InferenceError(
                     "Inference failed to find values for all positional "
                     "arguments to {func!r}: {unpacked_args!r} doesn't "
                     "correspond to {positional_arguments!r}.",
@@ -274,10 +293,10 @@ class CallSite:
         # Check if it's a default parameter.
         try:
             return funcnode.args.default_value(name).infer(context)
-        except exceptions.NoDefault:
+        except NoDefault:
             pass
-        raise exceptions.InferenceError(
-            "No value found for argument {name} to " "{func!r}",
+        raise InferenceError(
+            "No value found for argument {arg} to {func!r}",
             call_site=self,
             func=funcnode,
             arg=name,
